@@ -1,7 +1,8 @@
 robustRegBS<-function(formula,data,tune=4.685,m=TRUE,max.it=1000,tol=1e-5,anova.table=FALSE){
 
 bi<-FALSE
-if(m==FALSE){bi<-TRUE}
+#if(m==FALSE){bi<-TRUE}
+if(!m){bi<-TRUE}
 
 
 modelFrame=model.frame(formula,data)
@@ -38,7 +39,21 @@ for(i in 1:max.it){
    break}}
 }
 
-if(convergence==FALSE){b<-NULL;w<-NULL}
+#if(convergence==FALSE){b<-NULL;w<-NULL}
+#if(!convergence){b<-NULL;w<-NULL}
+
+#MSE Calc
+if(convergence){
+ ybarw<-sum(y*w)/sum(w)
+ ytild=fit_rcpp(X,b) #replaced ytild<-X%*%b
+ sserr<-sum(w*(y-ytild)^2)
+ dfr<-length(b)-1 
+ dferr<-length(y)-dfr-1
+ mse<-sserr/dferr}
+else{
+ b<-NULL;w<-NULL;mse<-NULL}
+
+
 if(convergence && anova.table){
 
 derivPsiBiSquare<-function(r,c){
@@ -51,35 +66,31 @@ return(psi)
 r3<-function(x){return(round(x,3))}
 r2<-function(x){return(round(x,2))}
 
- ybarw<-sum(y*w)/sum(w)
- ytild=fit_rcpp(X,b) #replaced ytild<-X%*%b
  ssreg<-sum(w*(ytild-ybarw)^2)
- sserr<-sum(w*(y-ytild)^2)
  sstot<-sum(w*(y-ybarw)^2)
- dfr<-length(b)-1
- dferr<-length(y)-dfr-1
  dftot<-length(y)-1
  msr<-ssreg/dfr
- mse<-sserr/dferr
  sbsq<-(s^2*(n^2/(n-length(b)))*sum(psiBS^2))/sum(derivPsiBiSquare(rstar,tune))^2
  F<-msr/sbsq
  W<-Diagonal(x=w[1:length(w),]) 
  c<-diag(x=solve(a=t(X)%*%W%*%X))
  sec<-sqrt(sbsq*c)
  t<-b/sec
- 
+ pval<-sapply(t, function(t) if(t>0){2*(1-pt(q=t,df=n-p))}else{2*(1-pt(q=t,df=n-p,lower.tail = FALSE))})
+
  cat("source  ","\t","SS","\t","\t","df","\t","MS","\t","\t","F","\n")
  cat("model   ","\t",r2(ssreg),"\t",dfr,"\t",r2(msr),"\t",r2(F),"\n")
  cat("error   ","\t",r2(sserr),"\t",dferr,"\n")
  cat("tot     ","\t",r2(sstot),"\t",dftot,"\n")
  cat("rsquared","\t",r3(ssreg/sstot),"\n")
- cat("mse     ","\t",mse,"\n")
- estimates<-cbind(b,sec,r2(t))
- #colnames(estimates)<-c("estimate","se","t")
+ cat("mse     ","\t",mse,"\n\n")
+ cat("Coefficients:\n")
+ estimates<-cbind(b,sec,r2(t),round(pval,5))
+ colnames(estimates)<-c("estimate","std error","t value","p value") 
  print(estimates)
  }
 
- object=list("coefficients"=b,"weights"=w)
+ object=list("coefficients"=b,"weights"=w, "mse"=mse)
  return(invisible(object)) 
 }
 
